pygerber.parser.blender.apertures.polygon module
================================================

.. automodule:: pygerber.parser.blender.apertures.polygon
   :members:
   :undoc-members:
   :show-inheritance:
